@@ -64,14 +64,17 @@ except Exception, e:
 
 from PapyEvents import *
 from PapyConvert import *
-PAPY_HAS_AUDIOVIDEO = 1
 
-try:
-    import PapyConference
-    import papyon.media.constants
-except ImportError, e:
-    PAPY_HAS_AUDIOVIDEO = 0
-    log.exception("You need gstreamer to use the Audio/Video calls support")
+PAPY_HAS_AUDIOVIDEO = False
+
+# We don't currently support audio/video conversations
+# because the required codecs aren't available in gstreamer
+#try:
+#    import PapyConference
+#    import papyon.media.constants
+#    PAPY_HAS_AUDIOVIDEO = True
+#except ImportError, e:
+#    log.exception("You need gstreamer to use the Audio/Video calls support")
 
 class Worker(e3.base.Worker, papyon.Client):
     ''' papylib's worker - an emesene extension for papyon library '''
@@ -145,10 +148,22 @@ class Worker(e3.base.Worker, papyon.Client):
             "last_avatar")
         self._set_status(presence)
 
+        # Set a bunch of client's capabilites
+        self.profile.client_capabilities.renders_gif = False
+        self.profile.client_capabilities.renders_isf = False
+        self.profile.client_capabilities.supports_activities = False
+        self.profile.client_capabilities.supports_winks = False
+        self.profile.client_capabilities.supports_shared_search = False
         global PAPY_HAS_AUDIOVIDEO
-        if PAPY_HAS_AUDIOVIDEO:
-            self.profile.client_capabilities.has_webcam = True
-            self.profile.client_capabilities.supports_rtc_video = True
+        self.profile.client_capabilities.supports_voice_im = PAPY_HAS_AUDIOVIDEO
+        self.profile.client_capabilities.supports_sip_invite = PAPY_HAS_AUDIOVIDEO
+        self.profile.client_capabilities.supports_tunneled_sip = PAPY_HAS_AUDIOVIDEO
+        self.profile.client_capabilities.supports_shared_drive = PAPY_HAS_AUDIOVIDEO
+        self.profile.client_capabilities.supports_rtc_video = PAPY_HAS_AUDIOVIDEO
+        self.profile.client_capabilities.has_webcam = PAPY_HAS_AUDIOVIDEO
+
+        self.profile.end_point_name = "emesene"
+        self.profile.privacy = papyon.profile.Privacy.BLOCK
 
         # initialize caches
         self.caches = e3.cache.CacheManager(self.session.config_dir.base_dir)
@@ -237,11 +252,11 @@ class Worker(e3.base.Worker, papyon.Client):
         if 'last' in avatars:
             contact.picture = os.path.join(avatars.path, 'last')
 
-        glib.timeout_add_seconds(5, lambda *arg: 
+        glib.timeout_add_seconds(5, lambda *arg:
             self._lazy_msnobj_checker(papycontact))
 
     def _lazy_msnobj_checker(self, papycontact):
-        ''' ugly hack because of https://github.com/emesene/emesene/issues/602 
+        ''' ugly hack because of https://github.com/emesene/emesene/issues/602
             aka papyon doesn't tell us msnobjects changed (and if we check
             too soon, they're None) '''
         self._on_contact_msnobject_changed(papycontact)
@@ -301,6 +316,7 @@ class Worker(e3.base.Worker, papyon.Client):
 
     def _on_conference_invite(self, call):
         '''handles a conference (call) invite'''
+        return # skip it, we don't support it
         account = call.peer.account
         if account in self.conversations:
             cid = self.conversations[account]
@@ -399,7 +415,11 @@ class Worker(e3.base.Worker, papyon.Client):
             download_path = self.session.config.get_or_set("download_folder",
                 e3.common.locations.downloads())
             if self.session.config.b_download_folder_per_account:
-                full_path = os.path.join(download_path, tr.sender, tr.filename)
+                full_path = os.path.join(download_path, tr.sender.account,
+                    tr.filename)
+                file_dir = os.path.join(download_path, tr.sender.account)
+                if not os.path.isdir(file_dir):
+                    os.mkdir(file_dir)
             else:
                 full_path = os.path.join(download_path, tr.filename)
             try:
@@ -465,7 +485,7 @@ class Worker(e3.base.Worker, papyon.Client):
                 [account])
 
         msgobj = e3.base.Message(e3.base.Message.TYPE_FLNMSG,
-            msg, account, None, flnmsg.date)
+            msg, account, None, flnmsg.date, flnmsg.sender.display_name)
         # override font size!
         msgobj.style.size = self.session.config.i_font_size
         self.session.conv_message(cid, account, msgobj, {})
@@ -517,29 +537,31 @@ class Worker(e3.base.Worker, papyon.Client):
         def download_failed(reason):
             log.error("Custom emoticon download failed: %s" % reason)
 
-        def download_ok(msnobj, em_path, download_failed_func):
+        def download_ok(msnobj, download_failed_func, received, filename, short):
             if msnobj._data is None:
                 log.warning("downloaded msnobj is None")
                 return
 
-            mo_fr = msnobj._friendly.replace("\x00", "")
-            emotes.insert_raw((mo_fr, msnobj._data))
+            shortcut, hash_ = emotes.insert_resized((short, msnobj._data),
+                                                    filename)
+
+            path = os.path.join(emotes.path, hash_)
+            received[short] = path
             self.session.p2p_finished(account, 'emoticon', msnobj._creator,
-                    mo_fr, em_path)
+                                      shortcut, path)
 
         for shortcut, msn_object in papymessage.msn_objects.iteritems():
             if shortcut in received_custom_emoticons:
                 break # avoid multi p2p
-            received_custom_emoticons[shortcut] = None
 
             emoticon_hash = msn_object._data_sha.encode("hex")
             emoticon_path = os.path.join(emotes.path, emoticon_hash)
-
             received_custom_emoticons[shortcut] = emoticon_path
 
-            if emoticon_hash not in emotes:
+            if not emotes.has_emote(shortcut):
                 self.msn_object_store.request(msn_object,
-                    (download_ok, emoticon_path, download_failed))
+                    (download_ok, download_failed,
+                     received_custom_emoticons, emoticon_hash, shortcut))
 
         self.session.conv_message(cid, account, msgobj,
                 received_custom_emoticons)
@@ -682,19 +704,34 @@ class Worker(e3.base.Worker, papyon.Client):
             return
         account = contact.account
         old_media = contact.media
-        contact.media = papycontact.current_media
+
+        contact.media = ' - '.join(papycontact.current_media) \
+                            if papycontact.current_media and \
+                            papycontact.current_media != ('', '') else ''
+
+        if contact.media != '':
+            contact.media = '♫ ' + contact.media
 
         if old_media == contact.media:
             return
 
-        if old_media == contact.media:
-            self.session.contact_attr_changed(account, 'media', old_media)
-            # TODO: log the media change
+        self.session.contact_attr_changed(account, 'media', old_media)
+        # TODO: log the media change
 
     def _on_contact_msnobject_changed(self, contact):
         '''called when a contact changes his display picture'''
         msn_object = contact.msn_object
-        if msn_object is None: #sometimes, happens.
+        if msn_object is None:
+            if STATUS_PAPY_TO_E3[contact.presence] != status.OFFLINE:
+                ctct = self.session.contacts.get(contact.account)
+                ctct.picture = None
+                avatars = self.caches.get_avatar_cache(contact.account)
+                if 'last' in avatars:
+                    try:
+                        os.remove(os.path.join(avatars.path, 'last'))
+                    except OSError, e:
+                        log.warning("Last picture remove failed: %s" % e)
+                self.session.picture_change_succeed(contact.account, None)
             return
         if msn_object._type == papyon.p2p.MSNObjectType.DISPLAY_PICTURE:
             avatars = self.caches.get_avatar_cache(contact.account)
@@ -1164,6 +1201,12 @@ class Worker(e3.base.Worker, papyon.Client):
             #TODO: check if this can happen, and prevent it (!)
             return
 
+        if picture_name == '':
+            self.profile.msn_object = None
+            self.session.contacts.me.picture = None
+            self.session.picture_change_succeed(self.session.account.account, None)
+            return
+
         try:
             f = open(picture_name, 'rb')
             avatar = f.read()
@@ -1259,7 +1302,8 @@ class Worker(e3.base.Worker, papyon.Client):
         '''
         conv = self.papyconv[cid]
         papycontact = self.contact_by_account(account)
-        conv._invite_user(papycontact)
+        if papycontact not in conv.participants:
+            conv._invite_user(papycontact)
 
     def _handle_action_send_message(self, cid, message,
             cedict=None, l_custom_emoticons=None):
