@@ -21,6 +21,16 @@
 import os
 import sys
 
+
+# Extract any non-GStreamer arguments, and leave the GStreamer arguments for
+# processing by GStreamer. This needs to be done before GStreamer is imported,
+# so that GStreamer doesn't hijack e.g. ``--help``.
+# NOTE This naive fix does not support values like ``bar`` in
+# ``--gst-foo bar``. Use equals to pass values, like ``--gst-foo=bar``.
+gstreamer_args = [arg for arg in sys.argv[1:] if arg.startswith('--gst')]
+emesene_args = [arg for arg in sys.argv[1:] if not arg.startswith('--gst')]
+sys.argv[1:] = gstreamer_args
+
 def we_are_frozen():
     """Returns whether we are frozen via py2exe.
     This will affect how we find out where we are located."""
@@ -57,7 +67,6 @@ import shutil
 import signal
 
 import debugger
-debugger.init()
 import logging
 log = logging.getLogger('emesene')
 
@@ -106,36 +115,7 @@ from pluginmanager import get_pluginmanager
 import extension
 import interfaces
 import gui
-
-# fix for gstreamer --help
-argv = sys.argv
-sys.argv = [argv[0]]
-
-class SingleInstanceOption(object):
-    '''option parser'''
-
-    def option_register(self):
-        '''register the options to parse by the command line option parser'''
-        option = optparse.Option("-s", "--single",
-            action="count", dest="single_instance", default=False,
-            help="Allow only one instance of emesene")
-        return option
-
-extension.implements('option provider')(SingleInstanceOption)
-extension.get_category('option provider').activate(SingleInstanceOption)
-
-class VerboseOption(object):
-    '''option parser'''
-
-    def option_register(self):
-        '''register the options to parse by the command line option parser'''
-        option = optparse.Option("-v", "--verbose",
-            action="count", dest="debuglevel", default=0,
-            help="Enable debug in console (add another -v to show debug)")
-        return option
-
-extension.implements('option provider')(VerboseOption)
-extension.get_category('option provider').activate(VerboseOption)
+import optionprovider
 
 class Controller(object):
     '''class that handle the transition between states of the windows'''
@@ -145,6 +125,7 @@ class Controller(object):
         self.window = None
         self.tray_icon = None
         self.conversations = []
+        self.minimize = False
         self.single_instance = None
         self.config = e3.common.Config()
         self.config_dir = e3.common.ConfigDir('emesene2')
@@ -169,9 +150,9 @@ class Controller(object):
         self._setup()
 
         signal.signal(signal.SIGINT,
-                lambda *args: glib.idle_add(self.close_session()))
+                lambda * args: glib.idle_add(self.close_session()))
         signal.signal(signal.SIGTERM,
-                lambda *args: glib.idle_add(self.close_session()))
+                lambda * args: glib.idle_add(self.close_session()))
 
     def _setup(self):
         '''register core extensions'''
@@ -247,6 +228,9 @@ class Controller(object):
             except ImportError:
                 pass
 
+        if options.minimized:
+            self.minimize = True
+
     def start(self, account=None):
         '''the entry point to the class'''
         windowcls = extension.get_default('window frame')
@@ -259,6 +243,9 @@ class Controller(object):
         use_http = self.config.get_or_set('b_use_http', False)
         self.go_login(proxy, use_http)
 
+        if self.minimize:
+            self.window.iconify()
+
     def go_login(self, proxy=None, use_http=None, cancel_clicked=False,
             no_autologin=False):
         '''shows the login GUI'''
@@ -300,7 +287,7 @@ class Controller(object):
 
         #let's start dbus and unity launcher
         if self.dbus_ext is not None:
-            self.dbus_ext.set_new_session(self.session)
+            self.dbus_ext.set_new_session(self.session, self.window)
         if self.unity_launcher is not None:
             self.unity_launcher.set_session(self.session)
 
@@ -466,6 +453,11 @@ class Controller(object):
         last_avatar_path = self.session.config_dir.get_path("last_avatar")
         self.session.load_config()
 
+        if 'msn' in self.session.SERVICES:
+            # keepalive conversations...or not
+            b_keepalive = self.session.config.get_or_set("b_papylib_keepalive", False)
+            self.session.get_worker().keepalive_conversations = b_keepalive
+
         image_name = self.session.config.get_or_set('image_theme', 'default')
         emote_name = self.session.config.get_or_set('emote_theme', 'default')
         sound_name = self.session.config.get_or_set('sound_theme', 'default')
@@ -504,7 +496,7 @@ class Controller(object):
         syn = extension.get_default('synch tool')
         # Check if a synch tool is present. Synch tool is only in the gtk gui.
         # Remove the following 'if' when it will be in the qt4 gui too.
-        if syn: 
+        if syn:
             user = self.session.account.account
             current_service = self.session.config.service
             syn = syn(self.session, current_service)
@@ -572,6 +564,7 @@ class Controller(object):
                 extension.get_and_instantiate('listening to',
                         self.window.content)
         self.set_default_extensions_from_config()
+        self.window.content.replace_extensions()
 
     def on_login_succeed(self):
         '''callback called on login succeed'''
@@ -622,6 +615,7 @@ class Controller(object):
         self.session.config.get_or_set('b_notify_contact_online', True)
         self.session.config.get_or_set('b_notify_contact_offline', True)
         self.session.config.get_or_set('b_notify_receive_message', True)
+        self.session.config.get_or_set('b_notify_only_when_available', True)
         self.session.config.get_or_set('b_show_userpanel', True)
         self.session.config.get_or_set('b_show_emoticons', True)
         self.session.config.get_or_set('b_show_header', True)
@@ -678,7 +672,7 @@ class Controller(object):
 
         notificationcls = extension.get_default('notification')
         self.notification = notificationcls(self.session)
-        self.soundPlayer = extension.get_and_instantiate('sound',self.session)
+        self.soundPlayer = extension.get_and_instantiate('sound', self.session)
 
     def on_new_conversation(self, cid, members, other_started=True):
         '''callback called when the other user does an action that justify
@@ -706,7 +700,10 @@ class Controller(object):
                 self.conversations.append(conv_manager)
 
                 if self.session.config.b_conv_minimized and other_started:
-                    window.iconify()
+                    if UnityLauncher is None:
+                        # FIXME: Dirty hack that makes sure windows don't
+                        # magically disappear on Oneiric
+                        window.iconify()
                     window.show()
                     window.iconify()
                 else:
@@ -723,7 +720,7 @@ class Controller(object):
         conversation = conv_manager.new_conversation(cid, members)
 
         conversation.update_data()
-        conversation.show() # puts widget visible
+        conversation.show(other_started) # puts widget visible
 
         # raises the container and grabs the focus
         # handles cases where window is minimized and ctrl+tab focus stealing
@@ -802,35 +799,13 @@ class Controller(object):
         '''save the avatar change as the last avatar'''
         if account == self.session.account.account:
             last_avatar_path = self.session.config_dir.get_path("last_avatar")
-            shutil.copy(path, last_avatar_path)
-
-class ExtensionDefault(object):
-    '''extension to register options for extensions'''
-
-    def option_register(self):
-        '''register options'''
-        option = optparse.Option('--ext-default', '-e')
-        option.type = 'string' #well, it's a extName:defaultValue string
-        option.action = 'callback'
-        option.callback = self.set_default
-        option.help = 'Set the default extension by name'
-        option.nargs = 1
-        return option
-
-    def set_default(self, option, opt, value, parser):
-        '''set default extensions'''
-        for couple in value.split(';'):
-            category_name, ext_name = [strng.strip()\
-                    for strng in couple.split(':', 2)]
-
-            if not extension.get_category(category_name)\
-                    .set_default_by_name(ext_name):
-                print 'Error setting extension "%s" default session to "%s"'\
-                        % (category_name, ext_name)
-
-extension.implements('option provider')(ExtensionDefault)
-extension.get_category('option provider').activate(ExtensionDefault)
-
+            if path:
+                shutil.copy(path, last_avatar_path)
+            else:
+                try:
+                    os.remove(last_avatar_path)
+                except OSError, e:
+                    log.warning("Cannot remove file: %s" % e)
 
 class PluggableOptionParser(object):
 
@@ -853,7 +828,6 @@ class PluggableOptionParser(object):
     def get_parsing(cls):
         return cls.results
 
-
 def main():
     """
     the main method of emesene
@@ -862,8 +836,8 @@ def main():
     extension.category_register('option provider', None,
             interfaces=interfaces.IOptionProvider)
     extension.get_category('option provider').multi_extension = True
-    extension.get_category('option provider').activate(ExtensionDefault)
-    options = PluggableOptionParser(argv)
+    extension.get_category('option provider').activate(optionprovider.ExtensionDefault)
+    options = PluggableOptionParser(args=emesene_args)
     options.read_options()
     main_method = extension.get_default('main')
     main_method(Controller)
