@@ -53,6 +53,7 @@ class ContactList(object):
 
         self.group_state = {}
         for (group, state) in group_state.iteritems():
+            group = group.encode("utf_8")
             try:
                 self.group_state[group] = bool(int(state))
             except ValueError:
@@ -349,7 +350,11 @@ class ContactList(object):
         '''
         return value.replace("[$", "[ $")
 
-    def format_nick(self, contact, escaped_information):
+    def escaper(self, text):
+        ''' escape the text, this is a toolkit dependant method '''
+        raise NotImplementedError
+
+    def format_nick(self, contact):
         '''replace the appearance of the template vars using the values of
         the contact
         # valid values:
@@ -361,41 +366,19 @@ class ContactList(object):
         # + BLOCKED
         # + NL
         '''
-        display_name, nick, message = escaped_information
-
-        #TODO: fix those "no-more-color" with msgplus codes, '&#173;'?
-        def fix_plus(text):
-            escaped = self.escape_tags(text)
-            pos = escaped.find("\xc2\xb7")
-            tail = ""
-            irc = "#&@'"
-            flag = False
-            while pos != -1:
-                try:
-                    char = escaped[pos+2]
-                    if char in irc and escaped.count("\xc2\xb7"+char)%2 != 0:
-                        tail = "\xc2\xb7" + char + tail
-                        irc = irc.replace(char,"")
-                    flag = flag or char == "$"
-                except:
-                    pos = pos+1
-                pos = escaped.find("\xc2\xb7",pos+2)
-            if flag:
-                tail += "no-more-color"
-            return escaped + tail
 
         template = self.nick_template
-        template = template.replace('[$NL]', '\n')
-        template = template.replace('[$NICK]',
-                fix_plus(nick))
+        template = template.replace('[$NICK]', self.escaper(contact.nick))
         template = template.replace('[$ACCOUNT]',
                 self.escape_tags(contact.account))
         template = template.replace('[$MESSAGE]',
-                fix_plus(message))
+                self.escaper(contact.message) if contact.media == '' else self.escaper(contact.media))
         template = template.replace('[$STATUS]',
                 self.escape_tags(e3.status.STATUS[contact.status]))
-        template = template.replace('[$DISPLAY_NAME]',
-                fix_plus(display_name))
+        template = template.replace('[$DISPLAY_NAME]', self.escaper(contact.display_name))
+        #people shouldn't be allowed to have \n in their name/pm
+        template = template.replace('\n', ' ')
+        template = template.replace('[$NL]', '\n')
 
         blocked_text = ''
 
@@ -406,7 +389,7 @@ class ContactList(object):
 
         return template
 
-    def format_group(self, group, escaped_name):
+    def format_group(self, group):
         '''replace the appearance of the template vars using the values of
         the group
         # valid values:
@@ -430,7 +413,7 @@ class ContactList(object):
                 template = template.replace('[$ONLINE_COUNT]', str(online))
                 template = template.replace('[$TOTAL_COUNT]', str(total))
 
-        template = template.replace('[$NAME]', self.escape_tags(escaped_name))
+        template = template.replace('[$NAME]', self.escape_tags(self.escaper(group.name)))
 
         return template
 
@@ -526,7 +509,7 @@ class ContactList(object):
         self.group_state[group.name] = False
         if self.is_searching or len(group.contacts) == 0:
             return
-        self.session.config.d_group_state[group.name] = "0"
+        self.session.config.d_group_state[group.name.decode("utf_8")] = "0"
 
     def on_group_expanded(self, group):
         '''called when a group is expanded, update the status of the
@@ -534,7 +517,7 @@ class ContactList(object):
         self.group_state[group.name] = True
         if self.is_searching:
             return
-        self.session.config.d_group_state[group.name] = "1"
+        self.session.config.d_group_state[group.name.decode("utf_8")] = "1"
 
     def compare_groups(self, group1, group2, order1=0, order2=0):
         '''compare two groups and return 1 if group1 should go first, 0
