@@ -23,6 +23,7 @@ import extension
 import e3
 import gui
 import MarkupParser
+import ConversationStatus
 
 from e3.common.RingBuffer import RingBuffer
 
@@ -41,8 +42,7 @@ class Conversation(object):
 
         self.cid = float(cid)
         self.icid = self.cid
-        self.formatter = e3.common.MessageFormatter(session.contacts.me)
-        self.first = True
+        self.formatter = e3.common.MessageFormatter()
 
         self._header_visible = True
         self._image_visible = True
@@ -61,6 +61,8 @@ class Conversation(object):
 
         self._style = None
 
+        self.conv_status = ConversationStatus.ConversationStatus(self.session.config)
+
         # the base class should override this attributes
         self.info = None
         self.input = None
@@ -208,6 +210,10 @@ class Conversation(object):
     def on_video_call(self):
         '''called when the user is requesting a video-only call'''
         raise NotImplementedError
+		
+    def on_toggle_avatar(self):
+        '''hide or show the avatar bar'''
+        raise NotImplementedError
 
     def on_voice_call(self):
         '''called when the user is requesting an audio-only call'''
@@ -220,6 +226,7 @@ class Conversation(object):
     def on_clean(self):
         '''called when the clean button is clicked'''
         self.output.clear()
+        self.conv_status.clear()
 
     def on_block_user(self):
         '''blocks the first user of the conversation'''
@@ -240,7 +247,9 @@ class Conversation(object):
         self.session.request_attention(self.cid)
         message = e3.Message(e3.Message.TYPE_NUDGE, '', None, None)
         message.body = _('You just sent a nudge!')
-        self.output.information(self.formatter, self.session.contacts.me, message)
+        msg = gui.Message.from_information(self.session.contacts.me, message)
+        self.output.information(self.formatter, msg)
+        self.conv_status.post_process_message(msg)
 
         self.play_nudge()
 
@@ -341,15 +350,23 @@ class Conversation(object):
 
     def _on_send_message(self, text):
         '''method called when the user press enter on the input text'''
-        custom_emoticons = gui.base.MarkupParser.get_custom_emotes(text, self.emcache.parse())
+        cedict = self.emcache.parse()
+        custom_emoticons = gui.base.MarkupParser.get_custom_emotes(text, cedict)
 
-        self.session.send_message(self.cid, text, self.cstyle, self.emcache.parse(), custom_emoticons)
+        self.session.send_message(self.cid, text, self.cstyle, cedict, custom_emoticons)
         message = e3.Message(e3.Message.TYPE_MESSAGE, text, None, self.cstyle)
-        self.output.send_message(self.formatter, self.session.contacts.me,
-                                 message, self.emcache.parse(), self.emcache.path, self.first)
+
+        msg = self.conv_status.pre_process_message(self.session.contacts.me,
+            message, False, cedict, self.emcache.path, message.timestamp,
+            message.type, self.cstyle)
+
+        self.output.send_message(self.formatter, msg)
+
+        self.conv_status.post_process_message(msg)
+
         self.messages.push(text)
         self.play_send()
-        self.first = False
+        self.conv_status.update_status()
 
     def on_receive_message(self, message, account, received_custom_emoticons):
         '''method called when a message arrives to the conversation'''
@@ -363,25 +380,37 @@ class Conversation(object):
                 message.style.color = e3.base.Color.from_hex(self.session.config.override_text_color)
 
             user_emcache = self.caches.get_emoticon_cache(account)
-            self.output.receive_message(self.formatter, contact, message,
-                    received_custom_emoticons, user_emcache.path, self.first)
+
+            msg = self.conv_status.pre_process_message(contact,
+                message, True, received_custom_emoticons, user_emcache.path,
+                message.timestamp, message.type, message.style)
+
+            self.output.receive_message(self.formatter, msg)
+
+            self.conv_status.post_process_message(msg)
+
             self.play_type()
 
         elif message.type == e3.Message.TYPE_NUDGE:
             message.body = _('%s just sent you a nudge!') % (contact.display_name,)
-            self.output.information(self.formatter, contact, message)
-            self.play_nudge()
+            msg = gui.Message.from_information(contact, message)
 
-        self.first = False
+            self.output.information(self.formatter, msg)
+            self.conv_status.post_process_message(msg)
+
+            self.play_nudge()
+        self.conv_status.update_status()
 
     def on_send_message_failed(self, errorCode):
         '''method called when a message fails to be delivered'''
         contact = self.session.contacts.me
         message = e3.Message(e3.Message.TYPE_MESSAGE, '', None, None)
         message.body = _('Error delivering message')
-        self.output.information(self.formatter, contact, message)
+        msg = gui.Message.from_information(contact, message)
 
-        self.first = False
+        self.output.information(self.formatter, msg)
+        self.conv_status.post_process_message(msg)
+        self.conv_status.update_status()
 
     def on_user_typing(self, account):
         '''method called when a someone is typing'''
@@ -456,7 +485,11 @@ class Conversation(object):
                 message = e3.base.Message(e3.base.Message.TYPE_MESSAGE, \
                 _('%s has joined the conversation') % (contact.display_name), \
                 account)
-                self.output.information(self.formatter, contact, message)
+                msg = gui.Message.from_information(contact, message)
+
+                self.output.information(self.formatter, msg)
+                self.conv_status.post_process_message(msg)
+
         self.update_data()
         
 
@@ -470,7 +503,10 @@ class Conversation(object):
                 message = e3.base.Message(e3.base.Message.TYPE_MESSAGE, \
                 _('%s has left the conversation') % (contact.display_name), \
                 account)
-                self.output.information(self.formatter, contact, message)
+                msg = gui.Message.from_information(contact, message)
+
+                self.output.information(self.formatter, msg)
+                self.conv_status.post_process_message(msg)
 
     def on_group_started(self):
         '''called when a group conversation starts'''
@@ -552,7 +588,7 @@ class Conversation(object):
         """
         play the receive sound
         """
-        if self.session.config.b_play_type:
+        if self.session.config.b_play_type and self.message_waiting:
             self.soundPlayer.play(gui.theme.sound_theme.sound_type)
 
     def cycle_history(self, change=-1):
