@@ -22,7 +22,6 @@ import sys
 import re
 import time
 import urllib
-import webbrowser
 
 import e3.base
 import gui
@@ -47,11 +46,11 @@ EMESENE_LICENSE = '''    emesene is free software; you can redistribute it and/o
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
-EMESENE_VERSION = "2.11.7"
-EMESENE_LAST_STABLE = "2.11.7"
+EMESENE_VERSION = "2.11.9"
+EMESENE_LAST_STABLE = "2.11.9"
 EMESENE_WEBSITE = "http://www.emesene.org"
 EMESENE_AUTHORS = "marianoguerra & c10ud"
-EMESENE_CONTRIBUTORS = [
+EMESENE_CONTRIBUTORS = [ # TODO: Load this from CONTRIBUTORS
 'Riccardo (c10ud) <c10ud.dev@gmail.com>',
 'Mariano Guerra <luismarianoguerra@gmail.com>',
 'arielj <arieljuod@gmail.com>',
@@ -189,7 +188,7 @@ class HelpHandler(object):
 
     def on_website_selected(self):
         '''called when the website item is selected'''
-        webbrowser.open(EMESENE_WEBSITE)
+        Desktop.open(EMESENE_WEBSITE)
 
     def on_debug_selected(self):
         '''called when the preference button is selected'''
@@ -209,7 +208,7 @@ class HelpHandler(object):
     def on_check_update_selected(self):
         ''' checks if a new stable version of emesene is available '''
         if sys.platform == "darwin":
-            subprocess.call(['open', '-a', '/Applications/emesene.app/Contents/Resources/emesene_updater.app'])
+            subprocess.call(['open', '/Applications/emesene.app/Contents/Resources/emesene updater.app'])
         else:
             f = urllib.urlopen("https://github.com/emesene/emesene/raw/master/emesene/gui/base/Handler.py")
             s = f.read()
@@ -565,6 +564,10 @@ class ConversationToolbarHandler(object):
         '''called when block/unblock button is selected'''
         self.conversation.on_block_user()
 
+    def on_toggle_avatar_selected(self):
+        '''hide or show the avatar bar'''
+        self.conversation.on_toggle_avatar()
+		
     def on_invite_video_call_selected(self):
         '''called when the user is requesting a video-only call'''
         self.conversation.on_video_call()
