@@ -24,14 +24,10 @@ import webkit
 import base64
 import xml.sax.saxutils
 
-import webbrowser
-
 import e3
 import gui
+from gui.base import Plus
 import utils
-import Renderers
-
-DISPLAY_NAME_LIMIT = 25
 
 class OutputView(webkit.WebView):
     '''a class that represents the output widget of a conversation
@@ -46,9 +42,6 @@ class OutputView(webkit.WebView):
         webkit_settings.set_property("enable-plugins", False)
 
         self.theme = theme
-        self.last_incoming = None
-        self.last_incoming_account = None
-        self.last_incoming_nickname = None
         self.ready = False
         self.pending = []
         self.add_emoticon_cb = add_emoticon_cb
@@ -56,6 +49,7 @@ class OutputView(webkit.WebView):
         self.connect('populate-popup', self.on_populate_popup)
         self.connect('navigation-requested', self.on_navigation_requested)
         self.connect('download-requested', self.on_download_requested)
+        self.connect('console-message', self._error_cb)
 
     def _loading_finished_cb(self, *args):
         '''callback called when the content finished loading
@@ -68,6 +62,11 @@ class OutputView(webkit.WebView):
             self.execute_script("scrollToBottom()")
         self.pending = []
 
+    def _error_cb(self, view, message, line, source_id):
+        '''called when a message is sent to the console'''
+        message = "Webkit message: %s %s %s" % (message, line, source_id)
+        log.debug(message)
+
     def clear(self, source="", target="", target_display="",
             source_img="", target_img=""):
         '''clear the content'''
@@ -77,44 +76,13 @@ class OutputView(webkit.WebView):
                 "text/html", "utf-8", utils.path_to_url(self.theme.path))
         self.pending = []
         self.ready = False
-        self.last_incoming = None
 
-    def add_message(self, msg, style=None, cedict={}, cedir=None):
+    def add_message(self, msg):
         '''add a message to the conversation'''
 
-        msg.alias = Renderers.msnplus_to_plain_text(msg.alias)
-        msg.display_name = Renderers.msnplus_to_plain_text(msg.display_name)
-        b_nick_check = bool(self.last_incoming_nickname != msg.display_name)
-        if b_nick_check:
-            self.last_incoming_nickname = msg.display_name
-        if(len(msg.alias) > DISPLAY_NAME_LIMIT):
-            msg.alias = msg.alias[0:DISPLAY_NAME_LIMIT] + "..."
-        if(len(msg.display_name) > DISPLAY_NAME_LIMIT):
-            msg.display_name = msg.display_name[0:DISPLAY_NAME_LIMIT] + "..."
-
-        if msg.incoming:
-            if self.last_incoming is None:
-                self.last_incoming = False
-
-            msg.first = not self.last_incoming
-
-            if self.last_incoming_account != msg.sender or b_nick_check:
-                msg.first = True
-
-            html = self.theme.format_incoming(msg, style, cedict, cedir)
-            self.last_incoming = True
-            self.last_incoming_account = msg.sender
-        else:
-            if self.last_incoming is None:
-                self.last_incoming = True
-
-            msg.first = self.last_incoming
-
-            html = self.theme.format_outgoing(msg, style, cedict, cedir)
-            self.last_incoming = False
+        html = self.theme.format(msg)
 
         if msg.type == "status":
-            self.last_incoming = None
             msg.first = True
 
         if msg.first:
@@ -136,15 +104,15 @@ class OutputView(webkit.WebView):
 
     def _set_text(self, text):
         '''set the text on the widget'''
-        self._textbox.load_string(text, "text/html", "utf-8", "")
+        self.load_string(text, "text/html", "utf-8", "")
         self.pending = []
         self.ready = False
 
     def _get_text(self):
         '''return the text of the widget'''
-        self._textbox.execute_script('oldtitle=document.title;document.title=document.documentElement.innerHTML;')
-        html = self._textbox.get_main_frame().get_title()
-        self._textbox.execute_script('document.title=oldtitle;')
+        self.execute_script('oldtitle=document.title;document.title=document.documentElement.innerHTML;')
+        html = self.get_main_frame().get_title()
+        self.execute_script('document.title=oldtitle;')
         return html
 
     text = property(fget=_get_text, fset=_set_text)
@@ -155,12 +123,13 @@ class OutputView(webkit.WebView):
         for i, child in enumerate(children):
             # Ditry hack. The first 3 buttons of the non-image menu
             # are insensitive
-            if i == 1 and child.get_property('sensitive'):
-                child.set_use_stock(False)
-                child.set_property("label", _("Save"))
-            else:
-                menu.remove(child)
-                child.destroy()
+            if len(children) == 4:
+                if i == 1 and child.get_property('sensitive'):
+                    child.set_use_stock(False)
+                    child.set_property("label", _("Save"))
+                else:
+                    menu.remove(child)
+                    child.destroy()
 
         select_all_item = gtk.MenuItem(label=_("Select All"))
         select_all_item.connect('activate', lambda *args: self.select_all())
@@ -181,7 +150,7 @@ class OutputView(webkit.WebView):
 
         if not href.startswith("file://"):
             log.info("link clicked: " + href)
-            webbrowser.open_new_tab(href)
+            gui.base.Desktop.open(href)
             return True
 
         return False
@@ -203,14 +172,11 @@ class OutputText(gtk.ScrolledWindow):
 
         self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.set_shadow_type(gtk.SHADOW_IN)
-        self._texts = []
         self.loaded = False
         picture = utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
 
         self.view = OutputView(gui.theme.conv_theme, "", "", "", picture,
                 picture, add_emoticon_cb)
-        self.view.connect('load-finished', self._loading_stop_cb)
-        self.view.connect('console-message', self._error_cb)
         self.clear()
         self.view.show()
         self.add(self.view)
@@ -218,39 +184,20 @@ class OutputText(gtk.ScrolledWindow):
     def clear(self, source="", target="", target_display="",
             source_img="", target_img=""):
         '''clear the content'''
-        self._texts = []
-        self.loaded = False
-        self.view.clear(source, Renderers.msnplus_to_plain_text(target), Renderers.msnplus_to_plain_text(target_display),
-            source_img, target_img)
+        self.view.clear(source, target, target_display, source_img, target_img)
 
-    def _error_cb(self, view, message, line, source_id):
-        '''called when a message is sent to the console'''
-        message = "Webkit message: %s %s %s" % (message, line, source_id)
-        log.debug(message)
-
-    def _loading_stop_cb(self, view, frame):
-        '''method called when the page finish loading'''
-        self.loaded = True
-        for text in self._texts:
-            self.append(text)
-
-        self._texts = []
-
-    def send_message(self, formatter, contact, message, cedict, cedir, is_first):
+    def send_message(self, formatter, msg):
         '''add a message to the widget'''
-        msg = gui.Message.from_contact(contact, message, is_first, False, message.timestamp)
-        self.view.add_message(msg, message.style, cedict, cedir)
+        self.view.add_message(msg)
 
-    def receive_message(self, formatter, contact, message, cedict, cedir, is_first):
+    def receive_message(self, formatter, msg):
         '''add a message to the widget'''
-        msg = gui.Message.from_contact(contact, message, is_first, True, message.timestamp)
-        self.view.add_message(msg, message.style, cedict, cedir)
+        self.view.add_message(msg)
 
-    def information(self, formatter, contact, message):
+    def information(self, formatter, msg):
         '''add an information message to the widget'''
-        msg = gui.Message.from_information(contact, message)
-        msg.message = Renderers.msnplus_to_plain_text(msg.message)
-        self.view.add_message(msg, None, None, None)
+        msg.message = Plus.msnplus_strip(msg.message)
+        self.view.add_message(msg)
 
     def update_p2p(self, account, _type, *what):
         ''' new p2p data has been received (custom emoticons) '''
