@@ -24,7 +24,7 @@ import os
 import gtk
 import pango
 import gobject
-import webbrowser
+import tempfile
 
 import e3
 import gui
@@ -48,8 +48,10 @@ class Dialog(object):
     def window_add_image(cls, window, stock_id):
         '''add a stock image as the first element of the window.hbox'''
         image = gtk.image_new_from_stock(stock_id, gtk.ICON_SIZE_DIALOG)
-        window.hbox.pack_start(image, False)
-        image.show()
+        alignment = gtk.Alignment(xalign=0.0, yalign=0.1)
+        alignment.add(image)
+        window.hbox.pack_start(alignment, False)
+        alignment.show_all()
 
         return image
 
@@ -136,7 +138,7 @@ class Dialog(object):
         args.append(window.entry.get_text())
 
         if response_cb:
-            if type(widget) == gtk.Entry:
+            if isinstance(widget, gtk.Entry):
                 response_cb(stock.ACCEPT, *args)
             else:
                 response_cb(*args)
@@ -219,7 +221,7 @@ class Dialog(object):
         window = gtk.Window()
         window.set_title(title)
         window.set_role("dialog")
-        window.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_MENU)
+        window.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
         window.set_default_size(150, 100)
         window.set_position(gtk.WIN_POS_CENTER)
         window.set_border_width(8)
@@ -297,9 +299,9 @@ class Dialog(object):
     @classmethod
     def exc_error(cls, message, response_cb=None, title=_("Error!")):
         '''show an error dialog displaying the message and the traceback;
-        this dialog should have only the option to close and the response 
+        this dialog should have only the option to close and the response
         callback is optional since in few cases one want to know when the error
-        dialog was closed, but it can happen, so return stock.CLOSE to the 
+        dialog was closed, but it can happen, so return stock.CLOSE to the
         callback if its set'''
         #cls.message_window('%s\n\n%s' % (message, traceback.format_exc()),
         #        gtk.STOCK_DIALOG_ERROR, response_cb, title).show()
@@ -416,7 +418,7 @@ class Dialog(object):
         you should call the response callback only once with a dict
         with two keys 'accepted' and 'rejected' and a list of mail
         addresses as values
-        '''    
+        '''
         dialog = AddBuddy(response_cb)
 
         for account, nick in accounts:
@@ -557,11 +559,11 @@ class Dialog(object):
         '''
         def on_website_hook(dialog, web):
             '''called when the website item is selected'''
-            webbrowser.open(web)
+            gui.base.Desktop.open(web)
 
         def on_email_hook(dialog, mail):
-            webbrowser.open("mailto://"+mail)
-
+            gui.base.Desktop.open("mailto://"+mail)
+            
         about = gtk.AboutDialog()
         gtk.about_dialog_set_url_hook(on_website_hook)
         gtk.about_dialog_set_email_hook(on_email_hook)
@@ -675,7 +677,7 @@ class Dialog(object):
         object of the current session the callback receives the response and
         a string containing the selected account
         '''
-        InviteWindow(session, callback).show()
+        InviteWindow(session, callback)
 
     @classmethod
     def login_preferences(cls, service, callback, use_http, proxy):
@@ -961,12 +963,42 @@ class Dialog(object):
         window.show_all()
 
     @classmethod
-    def sync_progress_window(cls, title, callback):
+    def progress_window(cls, title, callback):
         '''returns a progress window used for emesene 1 synch'''
         dialog = ProgressWindow(title, callback)
         dialog.show_all()
         return dialog
 
+    @classmethod
+    def broken_profile(cls, close_cb):
+        '''a dialog that asks you to fix your profile'''
+        message = _('''\
+Your live profile seems to be broken,
+which will cause you to experience issues
+with your display name, picture
+and/or personal message.
+
+You can fix it now by re-uploading
+your profile picture on the
+Live Messenger website that will open,
+or you can choose to fix it later.
+To fix your profile, emesene must be closed.
+Clicking Yes will close emesene.
+
+Do you want to fix your profile now?''')
+        def fix_profile(button, close_cb):
+            gui.base.Desktop.open("http://profile.live.com/details/Edit/Pic")
+            close_cb()
+
+        window = cls.common_window(message, gtk.STOCK_DIALOG_WARNING,
+            None, _("You have a broken profile"))
+        cls.add_button(window, gtk.STOCK_YES, stock.YES, fix_profile,
+            cls.default_cb, close_cb)
+        cls.add_button(window, gtk.STOCK_CANCEL, stock.CANCEL, None,
+            cls.default_cb)
+
+        window.show()
+
 class ImageChooser(gtk.FileChooserDialog):
     '''a class to select images'''
 
@@ -1207,20 +1239,17 @@ class EmotesWindow(gtk.Window):
         self.max_width = max_width
         self.emote_selected = emote_selected
 
-        rows = gui.theme.emote_theme.emotes_count/max_width # TODO: remove me
-
-        self.table = gtk.Table(max_width, rows)
+        self.table = gtk.Table(max_width)
         self._fill_emote_table(max_width)
         button = gtk.Button(_("Add emoticon"))
         button.set_image(gtk.image_new_from_stock(gtk.STOCK_ADD,
             gtk.ICON_SIZE_BUTTON))
         button.connect('clicked', self._on_add_custom_emote_selected)
-        
+
         self.box = gtk.VBox()
         self.box.pack_start(self.table)
         self.box.pack_start(button)
 
-
         self.add(self.box)
         self.box.show_all()
 
@@ -1262,41 +1291,33 @@ class EmotesWindow(gtk.Window):
 
         emote_theme = gui.theme.emote_theme
 
-        for shortcut, name in emote_theme.emotes.iteritems():
-            if name in emotes:
-                continue
+        def button_and_coords(shortcut, path):
             self.shortcut_list.append(shortcut)
-            emotes.append(name)
-
             column = count % columns
             row = count / columns
             button = gtk.Button()
-            path = emote_theme.emote_to_path(shortcut, True)
-
-            if path is None:
-                log.debug(shortcut + ' has no path')
-                continue
-
             button.set_image(self._get_emo_image(path, (20, 20)))
             button.set_tooltip_text(shortcut)
             button.set_relief(gtk.RELIEF_NONE)
             button.connect('clicked', self._on_emote_selected, shortcut)
+            return (column, row, button)
+
+        for shortcut, name in emote_theme.emotes.iteritems():
+            path = emote_theme.emote_to_path(shortcut, True)
+
+            if path is None or name in emotes:
+                continue
+            emotes.append(name)
+
+            column, row, button = button_and_coords(shortcut, path)
             self.table.attach(button, column, column + 1, row, row + 1)
 
             count += 1
 
         for shortcut, hash_ in self.emcache.list():
-            self.shortcut_list.append(shortcut)
-
-            column = count % columns
-            row = count / columns
-            button = gtk.Button()
             path = os.path.join(self.emcache.path, hash_)
 
-            button.set_image(self._get_emo_image(path, (20, 20)))
-            button.set_tooltip_text(shortcut)
-            button.set_relief(gtk.RELIEF_NONE)
-            button.connect('clicked', self._on_emote_selected, shortcut)
+            column, row, button = button_and_coords(shortcut, path)
             button.connect('button-release-event', self._on_emote_clicked, shortcut)
             self.table.attach(button, column, column + 1, row, row + 1)
 
@@ -1309,12 +1330,46 @@ class EmotesWindow(gtk.Window):
             if response != stock.ACCEPT:
                 return
             if size == CEChooser.SMALL:
-                size = 0
+                size = 16
             else:
-                size = 1
+                size = 50
 
-            #TODO: resize, etc. before inserting path, maybe use insert_raw.
-            self.emcache.insert((shortcut, path))
+            image = gtk.gdk.PixbufAnimation(path)
+            static = image.get_static_image()
+            width = static.get_width()
+            height = static.get_height()
+            if width <= size and height <= size:
+                #don't resize if less than size
+                resized_path = path
+            else:
+                if width > height:
+                    ratio = float(size)/width
+                else:
+                    ratio = float(size)/height
+                width = int(width*ratio)
+                height = int(height*ratio)
+
+                fd, resized_path = tempfile.mkstemp()
+                os.close(fd)
+
+                if image.is_static_image():
+                    #if static, resize using gtk
+                    image = static.scale_simple(width, height,
+                                                gtk.gdk.INTERP_NEAREST)
+
+                    if gtk.gdk.pixbuf_get_file_info(path)[0]['name'] == 'jpeg':
+                        format = 'jpeg'
+                    else:
+                        format = 'png'
+                    image.save(resized_path, format)
+                else:
+                    #resize animated images using imagemagick
+                    if not self.emcache.resize_with_imagemagick(path,
+                                                                resized_path,
+                                                                width, height):
+                        resized_path = path
+
+            self.emcache.insert((shortcut, resized_path))
 
         CEChooser(os.path.expanduser("~"), _on_ce_choosed, self.shortcut_list)
 
@@ -1361,7 +1416,7 @@ class EmotesWindow(gtk.Window):
                     Dialog.error(_("Empty shortcut"))
 
         window = Dialog.entry_window(_("New shortcut"), shortcut,
-                    _on_ce_edit_cb, _("Change shortcut"), 
+                    _on_ce_edit_cb, _("Change shortcut"),
                     self.emcache, shortcut, cedict[shortcut])
         window.show()
 
@@ -1432,7 +1487,6 @@ class InviteWindow(gtk.Window):
         vbox.pack_start(bbox, False)
         self.add(vbox)
 
-        vbox.show_all()
         badd.connect('clicked', self._on_add_clicked)
         bclose.connect('clicked', lambda *args: self.hide())
         search.connect('changed', self._on_search_changed)
@@ -1441,6 +1495,10 @@ class InviteWindow(gtk.Window):
         self.contact_list.contact_selected.subscribe(
             self._on_contact_selected)
         self.contact_list.fill()
+        self.set_modal(True)
+        self.show()
+        vbox.show_all()
+        
 
     def _on_key_press(self, widget, event):
         if event.keyval == gtk.keysyms.Escape:
@@ -1711,7 +1769,7 @@ class ProgressWindow(gtk.Window):
         self.buttoncancel.set_label(_("Cancel"))
         self.buttoncancel.connect('clicked', callback)
         self.connect('delete-event', callback)
-        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_MENU)
+        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
         self.set_default_size(300, 50)
         self.set_position(gtk.WIN_POS_CENTER)
         self.set_border_width(8)
@@ -1722,7 +1780,7 @@ class ProgressWindow(gtk.Window):
         vbox.pack_start(self.progressbar)
         vbox.pack_start(self.buttoncancel)
         self.add(vbox)
-        
+
     def update(self, progress):
         '''called when the progress is updated'''
         self.progressbar.set_fraction(progress / 100.0)
