@@ -94,6 +94,7 @@ class MainWindow(gtk.VBox):
             self._on_group_menu_selected)
 
         self.session.signals.mail_count_changed.subscribe(self._on_mail_count_changed)
+        self.session.signals.broken_profile.subscribe(self._on_broken_profile)
 
         scroll.add(self.contact_list)
         scroll.show_all()
@@ -104,6 +105,11 @@ class MainWindow(gtk.VBox):
         self.session.config.subscribe(self._on_show_userpanel_changed,
             'b_show_userpanel')
 
+    def _on_broken_profile(self):
+        '''called when a person has a broken profile'''
+        dialog = extension.get_default('dialog')
+        dialog.broken_profile(self.on_close)
+
     def _on_mail_count_changed(self, count):
         self.panel.mail.set_label("(%d)" % count)
 
@@ -151,6 +157,34 @@ class MainWindow(gtk.VBox):
         self.below_userlist.show()
         self.contact_list._set_accels(self.get_parent())
 
+    def _replace_below_userlist(self):
+        self.remove(self.below_userlist)
+        self.below_userlist = extension.get_and_instantiate('below userlist', self)
+        self.pack_start(self.below_userlist, False)
+        pos = len(self.get_children()) - 2
+        self.reorder_child(self.below_userlist, pos)
+        self.below_userlist.show()
+
+    def _replace_below_menu(self):
+        self.remove(self.below_menu)
+        self.below_menu = extension.get_and_instantiate('below menu', self)
+        self.pack_start(self.below_menu, False)
+        self.reorder_child(self.below_menu, 1)
+        self.below_menu.show()
+
+    def _replace_below_panel(self):
+        self.remove(self.below_panel)
+        self.below_panel = extension.get_and_instantiate('below panel', self)
+        self.pack_start(self.below_panel, False)
+        self.reorder_child(self.below_panel, 3)
+        self.below_panel.show()
+
+    def replace_extensions(self):
+        self._replace_below_userlist()
+        self._replace_below_menu()
+        self._replace_below_panel()
+
+
     def _on_entry_changed(self, entry, *args):
         '''called when the text on entry changes'''
         self.contact_list.filter_text = entry.get_text().lower()
@@ -232,6 +266,7 @@ class MainWindow(gtk.VBox):
             self._on_mail_count_changed)
         self.session.signals.contact_attr_changed.unsubscribe(
             self._on_contact_attr_changed)
+        self.session.signals.broken_profile.unsubscribe(self._on_broken_profile)
         self.panel.remove_subscriptions()
         self.on_disconnect_cb()
 
