@@ -17,18 +17,21 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk
-import webbrowser
 
 import e3.common
 import gui
 import utils
 import extension
+import stock
 
 from gui.base import MarkupParser
 
 import PluginWindow
+import ExtensionList
 
 import logging
+import os
+
 log = logging.getLogger('gtkui.Preferences')
 
 try:
@@ -39,12 +42,13 @@ except:
 
 # TODO: consider moving to nicer icons than stock ones.
 LIST = [
-    {'stock_id' : gtk.STOCK_FULLSCREEN,'text' : _('Interface')},
+    {'stock_id' : gtk.STOCK_PAGE_SETUP,'text' : _('Main Window')},
+    {'stock_id' : gtk.STOCK_PAGE_SETUP,'text' : _('Conversation Window')},
     {'stock_id' : gtk.STOCK_FLOPPY,'text' : _('Desktop')},
-    {'stock_id' : gtk.STOCK_MEDIA_NEXT,'text' : _('Sounds')},
+    {'stock_id' : gtk.STOCK_MEDIA_PLAY,'text' : _('Sounds')},
     {'stock_id' : gtk.STOCK_LEAVE_FULLSCREEN,'text' : _('Notifications')},
     {'stock_id' : gtk.STOCK_SELECT_COLOR,'text' : _('Theme')},
-    {'stock_id' : gtk.STOCK_DIALOG_WARNING,'text' : _('Extensions')},
+    {'stock_id' : gtk.STOCK_EXECUTE,'text' : _('Extensions')},
     {'stock_id' : gtk.STOCK_DISCONNECT,'text' : _('Plugins')},
 ]
 
@@ -66,16 +70,11 @@ class Preferences(gtk.Window):
         ''' TREE VIEW STUFF '''
         # Create the list store model for the treeview.
         self.listStore = gtk.ListStore(gtk.gdk.Pixbuf, str)
-
-
-
         # Create the TreeView
         treeView = gtk.TreeView(self.listStore)
-
         # Create the renders
         cellText = gtk.CellRendererText()
         cellPix = gtk.CellRendererPixbuf()
-
         # Create the single Tree Column
         treeViewColumn = gtk.TreeViewColumn(_('Categories'))
 
@@ -103,19 +102,23 @@ class Preferences(gtk.Window):
         hbox.pack_start(self.notebook, True, True)
         vbox.pack_start(hbox, True,True) # hbox, True, True
 
-        self.interface = Interface(session)
+        config_dir = e3.common.ConfigDir('emesene2')
+
+        self.main = MainWindow(session)
+        self.conversation = ConversationWindow(session)
         self.desktop = DesktopTab(session)
         self.sound = Sound(session)
         self.notification = Notification(session)
         self.theme = Theme(session)
         self.extension = Extension(session)
-        self.plugins = PluginWindow.PluginMainVBox(session)
+        self.plugins = PluginWindow.PluginMainVBox(
+            session, config_dir.join('plugins'))
 
         self.buttons = gtk.HButtonBox()
         self.buttons.set_border_width(2)
         self.buttons.set_layout(gtk.BUTTONBOX_END)
         self.close = gtk.Button(stock=gtk.STOCK_CLOSE)
-        self.close.connect('clicked', lambda *args: self.hide())
+        self.close.connect('clicked', self.save_and_hide)
         self.buttons.pack_start(self.close)
 
         vbox.pack_start(self.buttons, False, False)
@@ -124,7 +127,8 @@ class Preferences(gtk.Window):
         self.page_dict = []
 
         # Keep local copies of the objects
-        self.interface_page = self.interface
+        self.main_page = self.main
+        self.conversation_page = self.conversation
         self.desktop_page = self.desktop
         self.sound_page = self.sound
         self.notifications_page = self.notification
@@ -138,10 +142,15 @@ class Preferences(gtk.Window):
         self.add(vbox)
         vbox.show_all()
 
+    def save_and_hide(self, widget):
+        self.hide()
+        self.session.save_config()
+
     def remove_subscriptions(self):
-        self.interface.remove_subscriptions()
+        self.conversation.remove_subscriptions()
         self.sound.remove_subscriptions()
-        self.theme.remove_subscriptions()
+        if hasattr(self, 'msn_papylib'):
+            self.msn_papylib.privacy.remove_subscriptions()
 
     def remove_from_list(self, icon, text, page):
 
@@ -149,7 +158,7 @@ class Preferences(gtk.Window):
         self.page_dict.remove(page)
         num = self.notebook.page_num(page)
         self.notebook.remove_page(num)
-        self.__refresh_list()    
+        self.__refresh_list()
 
     def add_to_list(self, icon, text, page):
 
@@ -162,7 +171,8 @@ class Preferences(gtk.Window):
 
         # Whack the pages into a dict for future reference
 
-        self.page_dict.append(self.interface_page)
+        self.page_dict.append(self.main_page)
+        self.page_dict.append(self.conversation_page)
         self.page_dict.append(self.desktop_page)
         self.page_dict.append(self.sound_page)
         self.page_dict.append(self.notifications_page)
@@ -176,13 +186,26 @@ class Preferences(gtk.Window):
             self.listStore.append([self.render_icon(i['stock_id'],
                              gtk.ICON_SIZE_LARGE_TOOLBAR), i['text']])
 
-        if 'msn' in self.session.SERVICES: # only when session is papylib.
-            LIST.append({'stock_id' : gtk.STOCK_NETWORK,'text' : _('Live Messenger')})
-            self.listStore.append([self.render_icon(gtk.STOCK_NETWORK,
-                             gtk.ICON_SIZE_LARGE_TOOLBAR), _('Live Messenger')])
+        msn_in_list = False
+        for pair in LIST:
+            msn_in_list = msn_in_list or pair['text'] == _('Live Messenger')
+
+        if 'msn' in self.session.SERVICES:
+        # only when session is papylib.
+            if not msn_in_list:
+                LIST.append({'stock_id' : gtk.STOCK_NETWORK,
+                                 'text' : _('Live Messenger')})
+                self.listStore.append([self.render_icon(gtk.STOCK_NETWORK,
+                                       gtk.ICON_SIZE_LARGE_TOOLBAR),
+                                       _('Live Messenger')])
             self.msn_papylib = MSNPapylib(self.session)
             self.msn_papylib_page = self.msn_papylib
             self.page_dict.append(self.msn_papylib_page)
+        elif msn_in_list:
+            LIST.remove({'stock_id' : gtk.STOCK_NETWORK,
+                         'text' : _('Live Messenger')})
+            self.__refresh_list()
+
 
         for i in range(len(self.page_dict)):
            self.notebook.append_page(self.page_dict[i])
@@ -489,7 +512,7 @@ class BaseTable(gtk.Table):
         syn = syn(self.session, current_service)
         syn.show(True)
 
-class Interface(BaseTable):
+class MainWindow(BaseTable):
     """the panel to display/modify the config related to the gui
     """
 
@@ -500,6 +523,37 @@ class Interface(BaseTable):
         self.set_border_width(5)
         self.session = session
 
+        ContactList = extension.get_default('contact list')
+
+        self.append_markup('<b>'+_('User panel:')+'</b>')
+
+        self.append_check(_('Show user panel'),
+            'session.config.b_show_userpanel')
+
+        self.append_markup('<b>'+_('Contact list:')+'</b>')
+        self.append_range(_('Contact list avatar size'),
+            'session.config.i_avatar_size', 18, 64)
+
+        self.append_entry_default(_('Nick format'), 'nick',
+                'session.config.nick_template_clist', ContactList.NICK_TPL)
+        self.append_entry_default(_('Group format'), 'group',
+                'session.config.group_template', ContactList.GROUP_TPL)
+
+        self.show_all()
+
+class ConversationWindow(BaseTable):
+    """the panel to display/modify the config related to the gui
+    """
+
+    def __init__(self, session):
+        """constructor
+        """
+        BaseTable.__init__(self, 17, 1)
+        self.set_border_width(5)
+        self.session = session
+
+        #language option
+
         langs = list_dicts()
 
         self.spell_lang = self.session.config.get_or_set("spell_lang", "en")
@@ -513,17 +567,45 @@ class Interface(BaseTable):
                 self.lang_menu.set_active(index)
             index += 1
 
+        cb_check_spelling = self.create_check(
+            _('Enable spell check if available (requires %s)') % 'python-gtkspell',
+            'session.config.b_enable_spell_check')
+
+        h_lang_box = gtk.HBox()
+        h_lang_box.pack_start(cb_check_spelling)
+        h_lang_box.pack_start(self.lang_menu)
+
+        # override text color option
+
+        cb_override_text_color = self.create_check(_('Override incoming text color'),
+            'session.config.b_override_text_color')
+        self.session.config.subscribe(self._on_cb_override_text_color_toggled,
+            'b_override_text_color')
+
+        def on_color_selected(cb):
+            col = cb.get_color()
+            col_e3 = e3.base.Color(col.red, col.green, col.blue)
+            self.set_attr('session.config.override_text_color', '#'+col_e3.to_hex())
+
+        self.b_text_color = gtk.ColorButton(color=gtk.gdk.color_parse(
+                            self.get_attr('session.config.override_text_color')))
+        self.b_text_color.set_use_alpha(False)
+        self.b_text_color.connect('color-set', on_color_selected)
+        h_color_box = gtk.HBox()
+        h_color_box.pack_start(cb_override_text_color)
+        h_color_box.pack_start(self.b_text_color)
+
+        # preference list
+
         self.session.config.get_or_set('i_tab_position', 0)
-        self.tab_pos_cb = self.create_combo_with_label(_('Tab position'), self.get_tab_positions,
-                'session.config.i_tab_position',range(4))
+        self.tab_pos_cb = self.create_combo_with_label(_('Tab position'),
+            self.get_tab_positions, 'session.config.i_tab_position',range(4))
 
-        self.append_markup('<b>'+_('Main window:')+'</b>')
-        self.append_check(_('Show user panel'),
-            'session.config.b_show_userpanel')
-        self.append_markup('<b>'+_('Conversation window:')+'</b>')
         self.session.config.get_or_set('b_avatar_on_left', False)
         self.session.config.get_or_set('b_toolbar_small', False)
         self.session.config.get_or_set('b_conversation_tabs', True)
+        self.session.config.get_or_set('b_conv_tab_popup', False)
+        self.session.config.get_or_set('b_escape_hotkey', True)
         self.append_check(_('Tabbed Conversations'),
                 'session.config.b_conversation_tabs')
         self.append_row(self.tab_pos_cb)
@@ -536,32 +618,37 @@ class Interface(BaseTable):
             'session.config.b_show_info')
         self.append_check(_('Show conversation toolbar'),
             'session.config.b_show_toolbar')
+        self.append_check(_('Show tabs popup menu'),
+            'session.config.b_conv_tab_popup')
+        self.append_check(_('Enable escape hotkey to close tabs'),
+            'session.config.b_escape_hotkey')
         # small-toolbar sensitivity depends on conversation toolbar visibility
-        self.cb_small_toolbar = self.create_check(_('Small conversation toolbar'), 
+        self.cb_small_toolbar = self.create_check(_('Small conversation toolbar'),
             'session.config.b_toolbar_small')
         self.session.config.subscribe(self._on_cb_show_toolbar_changed,
             'b_show_toolbar')
         self.append_row(self.cb_small_toolbar)
 
         # Avatar-on-left sensitivity depends on side panel visibility
-        self.cb_avatar_left = self.create_check(_('Avatar on conversation left side'), 
+        self.cb_avatar_left = self.create_check(_('Avatar on conversation left side'),
             'session.config.b_avatar_on_left')
         self.session.config.subscribe(self._on_cb_side_panel_changed,
             'b_show_info')
         self.append_row(self.cb_avatar_left)
         self.append_check(_('Allow auto scroll in conversation'),
             'session.config.b_allow_auto_scroll')
-        self.append_check(_('Enable spell check if available (requires %s)') % 'python-gtkspell',
-            'session.config.b_enable_spell_check')
-        self.attach(self.lang_menu, 2, 3, 13, 14)
-        self.append_check(_('Show avatars in taskbar instead of status icons'), 
+        self.append_row(h_lang_box)
+        self.append_check(_('Show avatars in taskbar instead of status icons'),
             'session.config.b_show_avatar_in_taskbar')
 
-        self.append_range(_('Contact list avatar size'),
-            'session.config.i_avatar_size', 18, 64)
+        self.append_row(h_color_box)
+        #update ColorButton sensitive
+        self._on_cb_override_text_color_toggled(
+                self.session.config.get_or_set('b_override_text_color', False))
+
         self.append_range(_('Conversation avatar size'),
             'session.config.i_conv_avatar_size', 18, 128)
-        
+
         self.session.config.subscribe(self._on_spell_change,
             'b_enable_spell_check')
 
@@ -618,6 +705,14 @@ class Interface(BaseTable):
             'b_enable_spell_check')
         self.session.config.unsubscribe(self._on_conversation_tabs_change,
             'b_conversation_tabs')
+        self.session.config.unsubscribe(self._on_cb_override_text_color_toggled,
+            'b_override_text_color')
+
+    def _on_cb_override_text_color_toggled(self, value):
+        if value:
+            self.b_text_color.set_sensitive(True)
+        else:
+            self.b_text_color.set_sensitive(False)
 
 class Sound(BaseTable):
     """the panel to display/modify the config related to the sounds
@@ -684,6 +779,8 @@ class Notification(BaseTable):
         self.append_markup('<b>'+_('Messages events:')+'</b>')
         self.append_check(_('Notify on received message'),
             'session.config.b_notify_receive_message')
+        self.append_check(_('Only when available'),
+            'session.config.b_notify_only_when_available')
         self.show_all()
 
 class Theme(BaseTable):
@@ -693,90 +790,59 @@ class Theme(BaseTable):
     def __init__(self, session):
         """constructor
         """
-        BaseTable.__init__(self, 6, 1)
+        BaseTable.__init__(self, 1, 1)
         self.set_border_width(5)
         self.session = session
 
-        ContactList = extension.get_default('contact list')
-
         self.session.config.get_or_set('adium_theme', 'renkoo')
 
-        cb_override_text_color = self.create_check(_('Override incoming text color'),
-            'session.config.b_override_text_color')
-        self.session.config.subscribe(self._on_cb_override_text_color_toggled,
-            'b_override_text_color')
+        self.tabs = ExtensionList.ThemeList(session)
 
-        def on_color_selected(cb):
-            col = cb.get_color()
-            col_e3 = e3.base.Color(col.red, col.green, col.blue)
-            self.set_attr('session.config.override_text_color', '#'+col_e3.to_hex())
-
-        self.b_text_color = gtk.ColorButton(color=gtk.gdk.color_parse(
-                            self.get_attr('session.config.override_text_color')))
-        self.b_text_color.set_use_alpha(False)
-        self.b_text_color.connect('color-set', on_color_selected)
-        h_color_box = gtk.HBox()
-        h_color_box.pack_start(cb_override_text_color)
-        h_color_box.pack_start(self.b_text_color)
-
-        self.append_row(h_color_box)
-        #update ColorButton sensitive
-        self._on_cb_override_text_color_toggled(
-                self.session.config.get_or_set('b_override_text_color', False))
-
-        self.append_combo(_('Image theme'), gui.theme.get_image_themes,
+        self.tabs.append_theme_tab(_('Image theme'), 'images', gui.theme.image_themes,
             'session.config.image_theme')
-        self.append_combo(_('Sound theme'), gui.theme.get_sound_themes,
-            'session.config.sound_theme')
-        self.append_combo(_('Emote theme'), gui.theme.get_emote_themes,
+        self.tabs.append_theme_tab(_('Sound theme'), 'sounds', gui.theme.sound_themes,
+            'session.config.sound_theme', self._on_sound_combo_changed)
+        self.tabs.append_theme_tab(_('Emote theme'), 'emotes', gui.theme.emote_themes,
             'session.config.emote_theme')
-        self.adium_theme_combo = self.create_combo_with_label(_('Adium theme'),
-                gui.theme.get_adium_themes, 'session.config.adium_theme',
-                changed_cb = self._on_adium_theme_combo_changed)
-        self.append_row(self.adium_theme_combo)
-        hbox = gtk.HBox()
-        hbox.set_homogeneous(True)
+        adium_tab = self.tabs.append_theme_tab(_('Adium theme'), 'conversations', gui.theme.conv_themes,
+            'session.config.adium_theme', self._on_adium_theme_combo_changed)
+        self.add(self.tabs)
+
+        hbox = gtk.HBox(True)
         label = gtk.Label(_('Adium theme variant'))
         label.set_alignment(0.0, 0.5)
         self.adium_variant_combo = self.create_combo(gui.theme.conv_theme.get_theme_variants,
-                'session.config.adium_theme_variant')
+                'session.config.adium_theme_variant',
+                changed_cb = self._on_adium_variant_combo_changed)
+
         hbox.pack_start(label, True, True)
         hbox.pack_start(self.adium_variant_combo, False)
-        self.append_row(hbox, None)
+        adium_tab.pack_start(hbox, False)
 
-        self.append_entry_default(_('Nick format'), 'nick',
-                'session.config.nick_template_clist', ContactList.NICK_TPL)
-        self.append_entry_default(_('Group format'), 'group',
-                'session.config.group_template', ContactList.GROUP_TPL)
+    def on_update(self):
+        self.tabs.on_update()
 
-        self.add_button(_('Apply'), 0, 8,
-                self.on_redraw_main_screen, 0, 0)
+    def _on_sound_combo_changed(self, property_name, value):
+        #update sound theme config
+        self.set_attr(property_name, value)
+        gui.theme.sound_theme = value
 
-    def _on_adium_theme_combo_changed(self, combo, property_name, values=None):
+    def _on_adium_variant_combo_changed(self, combo, property_name, value):
+        variant_name = combo.get_active_text()
         #update adium variants combo
-        self.on_combo_changed(combo, property_name, values)
+        self.set_attr(property_name, variant_name)
+        gui.theme.conv_theme.variant = variant_name
 
-        image_name = self.session.config.get_or_set('image_theme', 'default')
-        emote_name = self.session.config.get_or_set('emote_theme', 'default')
-        sound_name = self.session.config.get_or_set('sound_theme', 'default')
-        conv_name = self.session.config.get_or_set('adium_theme',
-                'renkoo.AdiumMessagesStyle')
-        gui.theme.set_theme(image_name, emote_name, sound_name, conv_name)
+    def _on_adium_theme_combo_changed(self, property_name, value):
+        #update adium variants combo
+        self.set_attr(property_name, value)
+
+        gui.theme.conv_theme = value
         #clear combo
         self.adium_variant_combo.get_model().clear()
         self.fill_combo(self.adium_variant_combo,
             gui.theme.conv_theme.get_theme_variants, 'session.config.adium_theme_variant')
 
-    def _on_cb_override_text_color_toggled(self, value):
-        if value:
-            self.b_text_color.set_sensitive(True)
-        else:
-            self.b_text_color.set_sensitive(False)
-
-    def remove_subscriptions(self):
-        self.session.config.unsubscribe(self._on_cb_override_text_color_toggled,
-            'b_override_text_color')
-
 class Extension(BaseTable):
     """the panel to display/modify the config related to the extensions
     """
@@ -805,9 +871,9 @@ class Extension(BaseTable):
         category and the selected extension
         """
         def on_activate_link(label, uri):
-            webbrowser.open_new_tab(uri)
+            gui.base.Desktop.open(uri)
             return True
-        
+
         self.add_text(_('Categories'), 0, 0, True)
         self.add_text(_('Selected'), 0, 1, True)
         self.add_text('', 0, 2, True)
@@ -831,16 +897,10 @@ class Extension(BaseTable):
         self.add_button(_('Synch with emesene1'), 1, 8,
                 self.on_synch_emesene1, 0, 0)
 
-    def _get_categories(self):
-        ''' get available categories'''
-        categories = [ctg for ctg in extension.get_categories().keys() if len(extension.get_extensions(ctg)) > 1]
-        categories.sort()
-        return categories
-
     def _add_categories_and_extensions_combos(self):
         """add the widgets to display the extensions"""
 
-        categories = self._get_categories()
+        categories = extension.get_multiextension_categories()
 
         for item in categories:
             self.categories.append_text(item)
@@ -920,7 +980,7 @@ class Extension(BaseTable):
         model.clear()
         # fill it again with available categories
         # this is done because a plugin may have changed them
-        categories = self._get_categories()
+        categories = extension.get_multiextension_categories()
 
         for item in categories:
             model.append([item])
@@ -939,10 +999,10 @@ class DesktopTab(BaseTable):
         self.session = session
 
         self.append_markup('<b>'+_('Logger')+'</b>')
-        self.append_check(_('Enable logger'), 
+        self.append_check(_('Enable logger'),
                           'session.config.b_log_enabled')
         self.append_markup('<b>'+_('File transfers')+'</b>')
-        self.append_check(_('Sort received files by sender'), 
+        self.append_check(_('Sort received files by sender'),
                           'session.config.b_download_folder_per_account')
         self.add_text(_('Save files to:'), 0, 4, True)
 
@@ -977,6 +1037,11 @@ class MSNPapylib(BaseTable):
         vbox.set_border_width(10)
         align_prin.add(vbox)
 
+        c_keep = gtk.CheckButton(_("Keep-alive conversations"))
+        c_keep.set_active(self.session.config.b_papylib_keepalive)
+        c_keep.connect('toggled', self._on_keepalive_toggled)
+        vbox.pack_start(c_keep, False, False)
+
         l_text = gtk.Label(_('If you have problems with your nickname/message/picture '
                         'just click on this button, sign in with your account '
                         'and load a picture in your Live Profile. '
@@ -996,9 +1061,265 @@ class MSNPapylib(BaseTable):
 
         self.attach(align_prin, 0, 1, 0, 1)
 
+        # lists to manage contacts
+        self.privacy = PrivacySettings(self.session)
+        vbox.pack_start(self.privacy, True, True)
+
         self.show_all()
 
+    def _on_keepalive_toggled(self, widget):
+        ''' enable/disable conversation's keepalives in papyon '''
+        worker = self.session.get_worker()
+        worker.keepalive_conversations = widget.get_active()
+        self.session.config.b_papylib_keepalive = widget.get_active()
+
     def _on_live_profile_clicked(self, arg):
         ''' called when live profile button is clicked '''
-        webbrowser.open("http://profile.live.com/details/Edit/Pic")
+        gui.base.Desktop.open("http://profile.live.com/details/Edit/Pic")
 
+
+class PrivacySettings(gtk.VBox):
+    ''' A panel to manage contacts for MSN '''
+
+    def __init__(self, session):
+        ''' constructor '''
+        gtk.VBox.__init__(self)
+        self.config = session.config
+        self.session = session
+
+        # box with help message
+        eventBox = gtk.EventBox()
+        eventBox.modify_bg(gtk.STATE_NORMAL, gtk.gdk.Color('#EDDE5C'))
+        self.pack_start(eventBox, False, False)
+
+        # icon
+        box = gtk.HBox()
+        image = gtk.image_new_from_stock(gtk.STOCK_DIALOG_INFO,
+                                         gtk.ICON_SIZE_LARGE_TOOLBAR)
+        box.pack_start(image)
+        eventBox.add(box)
+
+        # tooltip labels
+        labels_box = gtk.VBox()
+        markup = '<span foreground="black"> %s </span>'
+        firstLabel = gtk.Label()
+        text = _('Red contacts are not in your contact list.')
+        firstLabel.set_markup(markup % text)
+        secondLabel = gtk.Label()
+        text = _('Yellow contacts don\'t have you in their contact list.')
+        secondLabel.set_markup(markup % text)
+        l_warning = gtk.Label()
+        text = _("<b>WARNING: The information provided below may be inaccurate.</b>")
+        l_warning.set_markup(markup % text)
+
+        labels_box.pack_start(firstLabel)
+        labels_box.pack_start(secondLabel)
+        labels_box.pack_start(l_warning)
+        box.pack_start(labels_box)
+
+        hbox = gtk.HBox()
+        self.add(hbox)
+
+        # allow list
+        scroll1 = gtk.ScrolledWindow()
+        scroll1.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+        scroll1.set_shadow_type(gtk.SHADOW_OUT)
+        hbox.add(scroll1)
+
+        self.allow_model = gtk.ListStore(str)
+        self.allow_model.set_sort_func(0, self._treesort_compare)
+        self.allow_view = gtk.TreeView(self.allow_model)
+        self.allow_view.connect("key-press-event", self._on_key_press)
+        self.allow_view.connect('button-press-event',
+                                self._on_right_click, self.allow_model)
+        self.allow_view.set_border_width(1)
+        scroll1.add(self.allow_view)
+
+        render1 = gtk.CellRendererText()
+        col1 = gtk.TreeViewColumn(_('Allow list:'), render1, text=0)
+        col1.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
+        col1.set_cell_data_func(render1, self._render_lists)
+        self.allow_view.append_column(col1)
+
+        # buttons
+        vbox = gtk.VBox()
+        button1 = gtk.Button()
+        image1 = gtk.image_new_from_stock(gtk.STOCK_GO_BACK,
+                                          gtk.ICON_SIZE_BUTTON)
+        button1.set_image(image1)
+        button1.connect('clicked', self.unblock)
+        vbox.pack_start(button1, True, False)
+
+        button2 = gtk.Button()
+        image2 = gtk.image_new_from_stock(gtk.STOCK_GO_FORWARD,
+                                          gtk.ICON_SIZE_BUTTON)
+        button2.set_image(image2)
+        button2.connect('clicked', self.block)
+        vbox.pack_start(button2, True, False)
+
+        hbox.pack_start(vbox, False)
+
+        # block list
+        scroll2 = gtk.ScrolledWindow()
+        scroll2.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
+        scroll2.set_shadow_type(gtk.SHADOW_OUT)
+        hbox.add(scroll2)
+
+        self.block_model = gtk.ListStore(str)
+        # 0 as there are only 1 column
+        self.block_model.set_sort_func(0, self._treesort_compare)
+        self.block_view = gtk.TreeView(self.block_model)
+        self.block_view.connect("key-press-event", self._on_key_press)
+        self.block_view.connect('button-press-event',
+                                self._on_right_click, self.block_model)
+        scroll2.add(self.block_view)
+
+        render2 = gtk.CellRendererText()
+        col2 = gtk.TreeViewColumn(_('Block list:'), render2, text=0)
+        col2.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
+        col2.set_cell_data_func(render2, self._render_lists)
+        self.block_view.append_column(col2)
+
+        # append contacts to the models
+        self._update_lists()
+
+        # subscribe to signals
+        self.session.signals.contact_add_succeed.subscribe(self._update_lists)
+        self.session.signals.contact_remove_succeed.subscribe(self._update_lists)
+        self.session.signals.contact_block_succeed.subscribe(self._update_lists)
+        self.session.signals.contact_unblock_succeed.subscribe(self._update_lists)
+        self.session.signals.contact_added_you.subscribe(self._update_lists)
+
+    def _treesort_compare(self, model, iter1, iter2, data=None):
+        data1 = model.get_value(iter1, 0).lower()
+        data2 = model.get_value(iter2, 0).lower()
+        return cmp(data1, data2)
+
+    def remove_subscriptions(self):
+        self.session.signals.contact_add_succeed.unsubscribe(self._update_lists)
+        self.session.signals.contact_remove_succeed.unsubscribe(self._update_lists)
+        self.session.signals.contact_block_succeed.unsubscribe(self._update_lists)
+        self.session.signals.contact_unblock_succeed.unsubscribe(self._update_lists)
+        self.session.signals.contact_added_you.unsubscribe(self._update_lists)
+
+    def _update_lists(self, contact=None):
+        ''' clears all the values of the models and fill them again '''
+        self.allow_model.clear()
+        self.block_model.clear()
+
+        for contact in self.session.get_allowed_contacts():
+            self.allow_model.append([contact])
+        self.allow_model.set_sort_column_id(0, gtk.SORT_ASCENDING)
+
+        for contact in self.session.get_blocked_contacts():
+            self.block_model.append([contact])
+        self.block_model.set_sort_column_id(0, gtk.SORT_ASCENDING)
+
+    def _on_right_click(self, view, event, model):
+        ''' shows a popup menu when a list is clicked '''
+        if event.button != 3:
+            return
+
+        # deselect the other view
+        if view is self.allow_view:
+            selection = self.block_view.get_selection()
+            selection.unselect_all()
+        else:
+            selection = self.allow_view.get_selection()
+            selection.unselect_all()
+
+        path = view.get_path_at_pos(int(event.x),int(event.y))
+        if not path:
+            selection = view.get_selection()
+            selection.unselect_all()
+            return
+
+        iter = model.get_iter(path[0])
+        contact = model.get_value(iter, 0)
+
+        menu = gtk.Menu()
+        item1 = gtk.MenuItem(_('Add to contacts'))
+        item1.connect('activate', lambda x: self.session.add_contact(contact))
+
+        # desactive this item if you already have the contact in your list
+        if self.session.is_forward(contact):
+            item1.set_sensitive(False)
+
+        if model is self.allow_model:
+            item2 = gtk.MenuItem(_('Move to block list'))
+            item2.connect('activate', lambda x: self.session.block(contact))
+        else:
+            item2 = gtk.MenuItem(_('Move to allow list'))
+            item2.connect('activate', lambda x: self.session.unblock(contact))
+
+        item3 = gtk.MenuItem(_('Delete'))
+        item3.connect('activate', self._delete_confirmation, iter, model)
+
+        # desactive these items if you don't have the contact in your list
+        if self.session.is_only_reverse(contact):
+            item3.set_sensitive(False)
+            # you can't block/unblock the contact either
+            item2.set_sensitive(False)
+
+        menu.append(item1)
+        menu.append(item2)
+        menu.append(item3)
+        menu.popup(None, None, None, event.button, event.time)
+        menu.show_all()
+
+    def block(self, button):
+        ''' blocks the selected contact '''
+        iter = self.allow_view.get_selection().get_selected()[1]
+        if not iter:
+            return
+
+        contact = self.allow_model.get_value(iter, 0)
+        self.session.block(contact)
+
+    def unblock(self, button):
+        ''' unblocks the selected contact '''
+        iter = self.block_view.get_selection().get_selected()[1]
+        if not iter:
+            return
+
+        contact = self.block_model.get_value(iter, 0)
+        self.session.unblock(contact)
+
+    def _render_lists(self, column, render, model, iter):
+        ''' changes the cell background according to the contact condition '''
+        contact = model.get_value(iter, 0)
+
+        if self.session.is_only_reverse(contact):
+            render.set_property('background', '#DC1415') #red
+        elif self.session.is_only_forward(contact):
+            render.set_property('background', '#E7E711') #yellow
+        else:
+            render.set_property('background', None)
+
+    def _on_key_press(self, widget, event):
+        ''' handles the keyboard events '''
+        if widget is self.allow_view and \
+            event.keyval in [gtk.keysyms.Right, gtk.keysyms.Return]:
+
+            self.block(None)
+
+        elif widget is self.block_view and \
+            event.keyval in [gtk.keysyms.Left, gtk.keysyms.Return]:
+
+            self.unblock(None)
+
+    def _delete_confirmation(self, item, iter, model):
+        ''' shows a confirmation dialog before delete the contact '''
+        message = _('Are you sure you want to delete %s from your authorized contacts?') % \
+                    model.get_value(iter, 0)
+
+        dialog = extension.get_default('dialog')
+        dialog.yes_no(message, self._delete_response, iter, model)
+
+    def _delete_response(self, action, iter=None, model=None):
+        ''' called when the delete is confirmed '''
+        try:
+            if action == stock.YES:
+                self.session.remove_contact(model.get_value(iter, 0))
+        except TypeError:
+            pass
