@@ -27,7 +27,7 @@ import gobject
 
 import gui
 from gui.base import Plus
-import ContactListParser
+import MarkupParser
 import extension
 from AvatarManager import AvatarManager
 
@@ -129,11 +129,15 @@ class CellRendererFunction(gtk.GenericCellRenderer):
         if self.markup:
             try:
                 decorated_markup = self.function(self.markup)
-            except Exception, error:
+            except Exception, error: #We really want to catch all exceptions
                 log.error("this nick: '%s' made the parser go crazy, striping. Error: %s" % (
                         self.markup, error))
+                try:
+                    decorated_markup = self.function(self.markup, False)
+                except Exception, error: #We really want to catch all exceptions
+                    log.error("Even stripping plus markup doesn't help. Error: %s" % error)
 
-                decorated_markup = Plus.msnplus_strip(self.markup)
+                    decorated_markup = self.markup
 
             layout.set_text(decorated_markup)
             return layout
@@ -145,36 +149,33 @@ class CellRendererFunction(gtk.GenericCellRenderer):
         widget.queue_resize()
 
 plus_or_noplus = 1 # 1 means plus, 0 means noplus
-# We still use the Plus parser from emesene 1
-plus_parser = Plus.MsnPlusMarkupMohrtutchy()
 
-def plus_text_parse(item):
+def plus_text_parse(item, plus):
     '''parse plus in the contact list'''
     global plus_or_noplus
     # get a plain string with objects
-    if plus_or_noplus:
-        item = plus_parser.replaceMarkup(item)
+    if plus_or_noplus and plus:
+        item = Plus.msnplus_parse(item)
     else:
-        item = plus_parser.removeMarkup(item)
+        item = Plus.msnplus_strip(item)
     return item
 
-def msnplus_to_list(text):
+def msnplus_to_list(text, plus=True):
     '''parse text and return a list of strings and gtk.gdk.Pixbufs'''
-    parser = ContactListParser.ContactListParser()
-    text = plus_text_parse(text)
-    text = parser.replace_markup(text)
-    text_list = parser.replace_emoticons(text)
+    text = plus_text_parse(text, plus)
+    text = MarkupParser.replace_markup(text)
+    text_list = MarkupParser.replace_emoticons(text)
     return text_list
 
-def msnplus_to_plain_text(txt):
-    ''' from a nasty string, returns a nice plain text string without
-    bells and whistles, just text '''
-    return plus_parser.removeMarkup(txt)
-
 class CellRendererPlus(CellRendererFunction):
     '''Nick renderer that parse the MSN+ markup, showing colors, gradients and
     effects'''
 
+    NAME = 'Cell Renderer Plus'
+    DESCRIPTION = _('Parse MSN+ markup, showing colors, gradients and effects')
+    AUTHOR = 'Mariano Guerra'
+    WEBSITE = 'www.emesene.org'
+
     def __init__(self):
         global plus_or_noplus
         plus_or_noplus = 1
@@ -188,6 +189,12 @@ class CellRendererNoPlus(CellRendererFunction):
     '''Nick renderer that "strip" MSN+ markup, not showing any effect/color,
     but improving the readability'''
 
+    NAME = 'Cell Renderer No Plus'
+    DESCRIPTION = _('Strip MSN+ markup, not showing any effect/color, but improving the readability')
+    AUTHOR = 'Mariano Guerra'
+    WEBSITE = 'www.emesene.org'
+
+
     def __init__(self):
         global plus_or_noplus
         plus_or_noplus = 0
@@ -305,11 +312,11 @@ class SmileyLayout(pango.Layout):
         self._base_attrlist = pango.AttrList()
         text = ''
 
-        if type(elements_list) in (str, unicode):
+        if isinstance(elements_list, basestring):
             elements_list = [elements_list]
 
         for element in elements_list:
-            if type(element) in (str, unicode):
+            if isinstance(element, basestring):
                 try:
                     attrl, ptxt, unused = pango.parse_markup(element, u'\x00')
                 except:
@@ -331,7 +338,7 @@ class SmileyLayout(pango.Layout):
                         break
 
                 text += ptxt
-            elif type(element) == gtk.gdk.Pixbuf:
+            elif isinstance(element, gtk.gdk.Pixbuf):
                 self._smilies[len(text)] = element
                 text += '_'
 
