@@ -83,7 +83,7 @@ class TabWidget(gtk.HBox):
 
         self.image.show()
         self.label.show()
-        self.close.show()
+        #self.close.show()
 
     def remove_subscriptions(self):
         self.session.config.unsubscribe(self.on_tab_position_change,'i_tab_position')
