@@ -18,13 +18,14 @@
 
 import gtk
 import gobject
+import os
 
 import e3
 import gui
 import utils
 import RichBuffer
 
-from gui.base import MarkupParser
+from gui.base import MarkupParser, Plus
 
 import logging
 log = logging.getLogger('gtkui.Textbox')
@@ -78,15 +79,36 @@ class TextBox(gtk.ScrolledWindow):
         '''append formatted text to the widget'''
         self._buffer.put_formatted(text)
         for anchor in self._buffer.widgets.keys():
-            widget = self._buffer.widgets[anchor]
-            self._textbox.add_child_at_anchor(widget, anchor)
-            self.widgets[anchor] = widget
-
-        self._buffer.widgets = {}
+            obj = self._buffer.widgets[anchor]
+            if obj is not None:
+                if isinstance(obj, gtk.Widget):
+                    self.add_widget_at_anchor(anchor, obj)
+                else:
+                    path, tip = obj
+                    try:
+                        self.add_image_at_anchor(anchor, path, tip)
+                    except gobject.GError:
+                        #custom emoticon not yet downloaded
+                        pass
 
         if scroll:
             self.scroll_to_end()
 
+    def add_image_at_anchor(self, anchor, path, tip):
+        ''' Reads path as image and adds the image in anchor '''
+        pixbuf = gtk.gdk.PixbufAnimation(path)
+        widget = gtk.Image()
+        widget.set_from_animation(pixbuf)
+        widget.set_tooltip_text(tip)
+        self.add_widget_at_anchor(anchor,widget)
+
+    def add_widget_at_anchor(self, anchor, widget):
+        self._textbox.add_child_at_anchor(widget, anchor)
+        self.widgets[anchor] = widget
+        if anchor in self._buffer.widgets.keys():
+            del self._buffer.widgets[anchor]
+        widget.show()
+
     def scroll_to_end(self):
         '''scroll to the end of the content'''
         end_iter = self._buffer.get_end_iter()
@@ -108,7 +130,7 @@ class TextBox(gtk.ScrolledWindow):
             return ""
 
         if start.get_offset() > end.get_offset():
-            start = end #set the right begining
+            start, end = end, start #set the right begining
 
         selection = self._buffer.get_slice(start,end)
         char = u"\uFFFC" #it means "widget or pixbuf here"
@@ -118,8 +140,11 @@ class TextBox(gtk.ScrolledWindow):
             if part == char:
                 anchor = start.get_child_anchor()
                 if anchor is not None:
-                    alt = self.widgets[anchor].get_property("tooltip-text")
-                    part = alt
+                    widget = self.widgets[anchor]
+                    if isinstance(widget, gtk.Image):
+                        part = widget.get_tooltip_text()
+                    elif isinstance(widget, gtk.Label):
+                        part = widget.get_text()
             return_string += part #new string with replacements
             start.forward_char()
         return return_string
@@ -167,17 +192,18 @@ class InputText(TextBox):
     AUTHOR = 'Mariano Guerra'
     WEBSITE = 'www.emesene.org'
 
-    def __init__(self, config, on_send_message, on_cycle_history, on_drag_data_received):
+    def __init__(self, session, on_send_message, on_cycle_history, on_drag_data_received):
         '''constructor'''
-        TextBox.__init__(self, config, on_drag_data_received)
+        TextBox.__init__(self, session.config, on_drag_data_received)
         self.on_send_message = on_send_message
         self.on_cycle_history = on_cycle_history
         self._tag = None
         self._textbox.connect('key-press-event', self._on_key_press_event)
         self._buffer.connect('changed', self.on_changed_event)
+        self.session = session
 
         self.changed = False
-        self.parse_timeout = gobject.timeout_add(500, self.parse_emotes)
+        self.parse_timeout = None
         self.invisible_tag = gtk.TextTag()
         self.invisible_tag.set_property('invisible', True)
         self._buffer.get_tag_table().add(self.invisible_tag)
@@ -228,53 +254,51 @@ class InputText(TextBox):
 
             self.on_cycle_history(1)
 
+        if self.parse_timeout is None:
+            self.parse_timeout = gobject.timeout_add(500, self.parse_emotes)        
+
     def parse_emotes(self):
         """
         parse the emoticons in the widget and replace them with
         images
         """
-        if not self.changed:
-            return True
+        if self.changed:
+          self.changed = False
+          emote_theme = gui.theme.emote_theme
 
-        self.changed = False
-        emote_theme = gui.theme.emote_theme
+          caches = e3.cache.CacheManager(self.session.config_dir.base_dir)
+          emcache = caches.get_emoticon_cache(self.session.account.account)
 
-        for code in emote_theme.emotes:
-            start = self._buffer.get_start_iter()
-            path = emote_theme.emote_to_path(code, True)
-            result = start.forward_search(code,
-                    gtk.TEXT_SEARCH_VISIBLE_ONLY)
+          for code, path in emote_theme.shortcuts_by_length(emcache.list()):
+              if not path.startswith(emote_theme.path):
+                  path = os.path.join(emcache.path, path)
 
-            if result is None:
-                continue
+              start = self._buffer.get_start_iter()
+              result = start.forward_search(code,
+                      gtk.TEXT_SEARCH_VISIBLE_ONLY)
 
-            while result is not None:
-                position, end = result
-                mark_begin = self._buffer.create_mark(None, start, False)
-                mark_end = self._buffer.create_mark(None, end, False)
-                image = utils.safe_gtk_image_load(path)
-                image.set_tooltip_text(code)
-                image.show()
+              if result is None:
+                  continue
 
-                self._buffer.delete(position, end)
-                pos = self._buffer.get_iter_at_mark(mark_end)
-                anchor = self._buffer.create_child_anchor(pos)
-                self._textbox.add_child_at_anchor(image, anchor)
+              while result is not None:
+                  position, end = result
+                  mark_begin = self._buffer.create_mark(None, start, False)
+                  mark_end = self._buffer.create_mark(None, end, False)
+                  
+                  self._buffer.delete(position, end)
+                  pos = self._buffer.get_iter_at_mark(mark_end)
+                  anchor = self._buffer.create_child_anchor(pos)
 
-                self.widgets[anchor] = image
+                  self.add_image_at_anchor(anchor, path, code)
 
-                start = self._buffer.get_iter_at_mark(mark_end)
-                result = start.forward_search(code,
-                        gtk.TEXT_SEARCH_VISIBLE_ONLY)
-                self._buffer.delete_mark(mark_begin)
-                self._buffer.delete_mark(mark_end)
+                  start = self._buffer.get_iter_at_mark(mark_end)
+                  result = start.forward_search(code,
+                          gtk.TEXT_SEARCH_VISIBLE_ONLY)
+                  self._buffer.delete_mark(mark_begin)
+                  self._buffer.delete_mark(mark_end)
 
-        return True
-
-    def stop_parse_emotes(self):
-        if self.parse_timeout is not None:
-            gobject.source_remove(self.parse_timeout)
         self.parse_timeout = None
+        return False
 
     def update_style(self, style):
         '''update the global style of the widget'''
@@ -350,49 +374,39 @@ class OutputText(TextBox):
         '''clear the content'''
         TextBox.clear(self)
     
-    def append(self, text, cedict, cepath, scroll=True):
+    def append(self, text, scroll=True):
         '''append formatted text to the widget'''
-        if self.config.b_show_emoticons:
-            text = MarkupParser.replace_emotes(text, cedict, cepath)
-
-        #Parse links
-        text = MarkupParser.urlify(text)
-
         TextBox.append(self, text, scroll)
 
-    def send_message(self, formatter, contact, message, cedict, cepath, is_first):
+    def send_message(self, formatter, msg):
         '''add a message to the widget'''
-        is_raw, consecutive, outgoing, first, last = \
-            formatter.format(contact, message.type, message.timestamp)
+        msg.alias = Plus.msnplus_strip(msg.alias)
+        msg.display_name = Plus.msnplus_strip(msg.display_name)
 
-        if is_raw:
-            middle = MarkupParser.escape(message.body)
-        else:
-            middle = MarkupParser.escape(message.body)
-            middle = e3.common.add_style_to_message(middle, message.style, False)
+        text = formatter.format(msg)
+        self.append(text, self.config.b_allow_auto_scroll)
 
-        all_ = first + middle + last
-        self.append(all_, cedict, cepath, self.config.b_allow_auto_scroll)
-
-    def receive_message(self, formatter, contact, message, cedict, cepath, is_first):
+    def receive_message(self, formatter, msg):
         '''add a message to the widget'''
-        is_raw, consecutive, outgoing, first, last = \
-            formatter.format(contact, None, message.timestamp)
+        msg.alias = Plus.msnplus_strip(msg.alias)
+        msg.display_name = Plus.msnplus_strip(msg.display_name)
 
-        if not is_raw:
-            middle = e3.common.add_style_to_message(message.body, message.style)
-        else:
-            middle = MarkupParser.escape(message.body)
+        text = formatter.format(msg)
+        self.append(text, self.config.b_allow_auto_scroll)
 
-        self.append(first + middle + last, cedict, cepath,
-                    self.config.b_allow_auto_scroll)
-
-    def information(self, formatter, contact, message):
+    def information(self, formatter, msg):
         '''add an information message to the widget'''
-        self.append(formatter.format_information(message.body), None, None,
+        msg.message = Plus.msnplus_strip(msg.message)
+        self.append(formatter.format_information(msg.message),
                 self.config.b_allow_auto_scroll)
 
     def update_p2p(self, account, _type, *what):
         ''' new p2p data has been received (custom emoticons) '''
-        return # NotImplemented
+        if _type == 'emoticon':
+            for anchor in self._buffer.widgets.keys():
+                obj = self._buffer.widgets[anchor]
+                if not isinstance(obj, gtk.Widget):
+                    path, tip = obj
+                    if path == what[2]:
+                        self.add_image_at_anchor(anchor, path, tip)
 
