@@ -37,13 +37,14 @@ class Window(gtk.Window):
         self.set_title("emesene")
         image_theme = gui.theme.image_theme
         try:
-            gtk.window_set_default_icon_list(\
-                 utils.safe_gtk_image_load(image_theme.logo16).get_pixbuf(), \
-                 utils.safe_gtk_image_load(image_theme.logo32).get_pixbuf(), \
-                 utils.safe_gtk_image_load(image_theme.logo48).get_pixbuf(), \
+            gtk.window_set_default_icon_list(
+                 utils.safe_gtk_image_load(image_theme.logo16).get_pixbuf(),
+                 utils.safe_gtk_image_load(image_theme.logo32).get_pixbuf(),
+                 utils.safe_gtk_image_load(image_theme.logo48).get_pixbuf(),
                  utils.safe_gtk_image_load(image_theme.logo96).get_pixbuf())
         except:
-            gtk.window_set_default_icon(image_theme.logo)
+            gtk.window_set_default_icon(
+                utils.safe_gtk_image_load(image_theme.logo).get_pixbuf())
 
         self.cb_on_close = cb_on_close
         self.cb_on_quit = cb_on_close
@@ -68,7 +69,7 @@ class Window(gtk.Window):
             self.remove(self.get_child())
             self.content = None
 
-    def go_login(self, callback,on_preferences_changed,
+    def go_login(self, callback, on_preferences_changed,
            config=None, config_dir=None, config_path=None,
            proxy=None, use_http=None, session_id=None, cancel_clicked=False,
            no_autologin=False):
@@ -202,3 +203,12 @@ class Window(gtk.Window):
         '''return True is window is maximized, False otherwise
         '''
         return self._state & gtk.gdk.WINDOW_STATE_MAXIMIZED == gtk.gdk.WINDOW_STATE_MAXIMIZED
+
+    def iconify(self):
+        ''' yes, we want to iconify the window, really '''
+        gtk.Window.iconify(self)
+
+    def present(self):
+        ''' raise the window '''
+        gtk.Window.present(self)
+
